<?php

namespace Bixo\Group\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Group\Http\Resources\GroupResource;
use Bixo\Group\Http\Resources\GroupsCollection;
use Bixo\Group\Scopes\GroupPublicScope;
use Bixo\Group\Models\Group;

class GroupPublicController extends BaseController
{

    /**
     * Show group's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Group::pushScope(new RequestScope())
            ->pushScope(new GroupPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $groups = new GroupsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('group::group.names'))
            ->view('group::public.group.index')
            ->data(compact('groups', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show group.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Group::findBySlug($slug);
        $data = new GroupResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('group::group.name'))
            ->view('group::public.group.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
